@@ -6,7 +6,7 @@ BEGIN {
 		use strict;
 
 		# a.ammr a.a anne d'existence, mm mois, r release
-		$VERSION	= 1.5092; 
+		$VERSION	= 1.5093; 
 		$YEAR	= '2020';
 		@ISA		= qw(Exporter);
 		@EXPORT	= qw(oEdtk_release);
@@ -15,6 +15,8 @@ BEGIN {
 #
 # CODE - DOC AT THE END
 #
+use strict;
+use warnings;
 
 sub oEdtk_release {
 	# warn "DEBUG: >$?< \nDEBUG: >$@<\n";
